import django.db.models.deletion
from django.contrib.contenttypes.models import ContentType
from django.db import migrations, models


def create_repository_admin(apps, schema_editor):
    Right = apps.get_model('users', 'Right')
    Repository = apps.get_model('dataimport', 'Repository')
    # Define repositories admins from credentials used during the import
    Right.objects.bulk_create([
        Right(
            user_id=repo.credentials.user_id,
            content_type_id=ContentType.objects.get_for_model(Repository).id,
            content_id=repo.id,
            level=100
        ) for repo in Repository.objects.exclude(credentials__isnull=True)
    ])


class Migration(migrations.Migration):

    dependencies = [
        ('dataimport', '0026_larger_content_type'),
        ('users', '0011_corpus_rights'),
    ]

    operations = [
        migrations.AddField(
            model_name='worker',
            name='public',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='workerversion',
            name='worker',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='versions', to='dataimport.worker'),
        ),
        migrations.RunPython(
            create_repository_admin,
            reverse_code=migrations.RunPython.noop,
            elidable=True
        )
    ]
