# Generated by Django 3.2.5 on 2021-11-04 08:14

from collections import defaultdict

from django.db import migrations

from arkindex.dataimport.utils import hash_object


def use_worker_configuration(apps, schema_editor):
    WorkerRun = apps.get_model('dataimport', 'WorkerRun')
    WorkerConfiguration = apps.get_model('dataimport', 'WorkerConfiguration')

    indexes = defaultdict(int)

    for worker_run in WorkerRun.objects.filter(configuration__isnull=True) \
                                       .exclude(old_configuration={}) \
                                       .select_related('version__worker'):
        worker = worker_run.version.worker
        worker_configuration, created = WorkerConfiguration.objects.get_or_create(
            worker=worker,
            configuration_hash=hash_object(worker_run.old_configuration),
            defaults={
                'name': f'config for {worker.name} n°{indexes[worker.id]+1}',
                'configuration': worker_run.old_configuration
            }
        )
        indexes[worker.id] += created
        worker_run.configuration = worker_configuration
        worker_run.save()


def use_old_configuration(apps, schema_editor):
    WorkerRun = apps.get_model('dataimport', 'WorkerRun')

    worker_runs = WorkerRun.objects.filter(configuration__isnull=False).select_related('configuration')
    for worker_run in worker_runs:
        worker_run.old_configuration = worker_run.configuration.configuration
    WorkerRun.objects.bulk_update(worker_runs, ['old_configuration'])


class Migration(migrations.Migration):

    dependencies = [
        ('dataimport', '0039_worker_configuration'),
    ]

    operations = [
        migrations.RunPython(
            use_worker_configuration,
            reverse_code=use_old_configuration,
            elidable=True,
        ),
    ]
