-- This filters worker versions to only include those used in any of the kinds
-- of ML results we have.  Doing it using LEFT JOIN would require 10 joins and
-- fills up the RAM.  Adding DISTINCT to all the SELECT queries of the UNION
-- slows this query down by ~20%.  Using multiple INs instead of a UNION makes
-- this query twice as slow.
SELECT version.id, worker.name, worker.slug, worker.type, revision.hash, repository.url
FROM dataimport_workerversion version
INNER JOIN dataimport_worker worker ON (version.worker_id = worker.id)
INNER JOIN dataimport_repository repository ON (worker.repository_id = repository.id)
INNER JOIN dataimport_revision revision ON (version.revision_id = revision.id)
WHERE version.id IN (
    SELECT worker_version_id FROM documents_element WHERE corpus_id = '{corpus_id}'::uuid
UNION
    SELECT worker_version_id FROM documents_entity WHERE corpus_id = '{corpus_id}'::uuid
UNION
    SELECT classification.worker_version_id
    FROM documents_classification classification
    INNER JOIN documents_element element ON (element.id = classification.element_id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
UNION
    SELECT transcription.worker_version_id
    FROM documents_transcription transcription
    INNER JOIN documents_element element ON (element.id = transcription.element_id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
UNION
    SELECT te.worker_version_id
    FROM documents_transcriptionentity te
    INNER JOIN documents_entity entity ON (te.entity_id = entity.id)
    WHERE entity.corpus_id = '{corpus_id}'::uuid
UNION
    SELECT md.worker_version_id
    FROM documents_metadata md
    INNER JOIN documents_element element ON (md.element_id = element.id)
    WHERE element.corpus_id = '{corpus_id}'::uuid
)
