from django.conf import settings
from django.utils.decorators import method_decorator
from django.views.decorators.cache import cache_page
from drf_spectacular.renderers import OpenApiJsonRenderer, OpenApiYamlRenderer
from drf_spectacular.utils import extend_schema
from drf_spectacular.views import SpectacularAPIView


class OldOpenApiYamlRenderer(OpenApiYamlRenderer):
    """
    Restores DRF's `?format=openapi` for backwards compatibility
    """
    format = 'openapi'


class OldOpenApiJsonRenderer(OpenApiJsonRenderer):
    """
    Restores DRF's `?format=openapi-json` for backwards compatibility
    """
    format = 'openapi-json'


@method_decorator(cache_page(86400, key_prefix=settings.VERSION), name='dispatch')
@extend_schema(exclude=True)
class OpenApiSchemaView(SpectacularAPIView):
    renderer_classes = SpectacularAPIView.renderer_classes + [
        OldOpenApiYamlRenderer,
        OldOpenApiJsonRenderer,
    ]
